//+------------------------------------------------------------------+
//|                                                     Analyzer.mq4 |
//|                      Copyright  2006, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
#property copyright "Copyright  2006, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net"
#import "shell32.dll"
int ShellExecuteA(int hWnd,string lpVerb,string lpFile,int lpParameters,int lpDirectory,int nCmdShow);
#import

#property show_inputs
#define SYMBOLS_MAX 1024
#define DEALS          0
#define BUY_LOTS       1
#define BUY_PRICE      2
#define SELL_LOTS      3
#define SELL_PRICE     4
#define NET_LOTS       5
#define PROFIT         6

extern string ExtFileName="Analyze.htm";
extern bool   ExtHTML=true;

int    ExtHandle=-1;
string ExtSymbols[SYMBOLS_MAX];
int    ExtSymbolsTotal=0;
double ExtSymbolsSummaries[SYMBOLS_MAX][7];
//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
  {
   double profit;
   int    i,index,type,total=OrdersTotal();
//----
   for(i=0; i<total; i++)
     {
      if(!OrderSelect(i,SELECT_BY_POS)) continue;
      type=OrderType();
      if(type!=OP_BUY && type!=OP_SELL) continue;
      index=SymbolsIndex(OrderSymbol());
      if(index<0 || index>=SYMBOLS_MAX) continue;
      //----
      ExtSymbolsSummaries[index][DEALS]++;
      profit=OrderProfit()+OrderCommission()+OrderSwap();
      ExtSymbolsSummaries[index][PROFIT]+=profit;
      if(type==OP_BUY)
        {
         ExtSymbolsSummaries[index][BUY_LOTS]+=OrderLots();
         ExtSymbolsSummaries[index][BUY_PRICE]+=OrderOpenPrice();
        }
      else
        {
         ExtSymbolsSummaries[index][SELL_LOTS]+=OrderLots();
         ExtSymbolsSummaries[index][SELL_PRICE]+=OrderOpenPrice();
        }
     }
//----
   if(ExtSymbolsTotal>0)
     {
      if(ExtHTML) WriteHTML();
      else        WriteText();
      if(ExtHandle>=0)
        {
         FileClose(ExtHandle);
         string filename=StringConcatenate(TerminalPath(),"\\experts\\files\\",ExtFileName);
         ShellExecuteA(NULL,"open",filename,NULL,NULL,5);
        }
     }
//----
   return(0);
  }
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int SymbolsIndex(string SymbolName)
  {
   bool found=false;
//----
   for(int i=0; i<ExtSymbolsTotal; i++)
     {
      if(SymbolName==ExtSymbols[i])
        {
         found=true;
         break;
        }
     }
//----
   if(found) return(i);
   if(ExtSymbolsTotal>=SYMBOLS_MAX) return(-1);
//----
   i=ExtSymbolsTotal;
   ExtSymbolsTotal++;
   ExtSymbols[i]=SymbolName;
   ExtSymbolsSummaries[i][DEALS]=0;
   ExtSymbolsSummaries[i][BUY_LOTS]=0;
   ExtSymbolsSummaries[i][BUY_PRICE]=0;
   ExtSymbolsSummaries[i][SELL_LOTS]=0;
   ExtSymbolsSummaries[i][SELL_PRICE]=0;
   ExtSymbolsSummaries[i][NET_LOTS]=0;
   ExtSymbolsSummaries[i][PROFIT]=0;
//----
   return(i);
  }
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void WriteHTML()
  {
   ExtHandle=FileOpen(ExtFileName,FILE_BIN|FILE_WRITE);
   if(ExtHandle<0) return;
//----
   string str="<html>\r\n<head>\r\n<title>Analyzer report</title>\r\n";
   FileWriteString(ExtHandle,str,StringLen(str));
   str="<meta name=\"script generator\" content=\"MetaQuotes Software Corp.\">\r\n";
   FileWriteString(ExtHandle,str,StringLen(str));
   str="<link rel=\"help\" href=\"http://www.metaquotes.net\">\r\n</head>\r\n";
   FileWriteString(ExtHandle,str,StringLen(str));
   str="<body topmargin=1 marginheight=1>\r\n";
   FileWriteString(ExtHandle,str,StringLen(str));
   str="<div align=center>\r\n";
   FileWriteString(ExtHandle,str,StringLen(str));
   str="<div style=\"font: 20pt Times New Roman\"><b>";
   FileWriteString(ExtHandle,str,StringLen(str));
   str=StringConcatenate("Account #",AccountNumber(),"  at ",TimeToStr(TimeLocal()));
   FileWriteString(ExtHandle,str,StringLen(str));
   str="</b></div>\r\n";
   FileWriteString(ExtHandle,str,StringLen(str));
   str="<table width=820 cellspacing=1 cellpadding=3 border=1>";
   FileWriteString(ExtHandle,str,StringLen(str));
//----
   str="<td>Symbols</td><td>Deals</td><td>Buy lots</td><td>Buy price</td><td>Sell lots</td><td>Sell price</td><td>Net lots</td><td>Profit</td></tr>\r\n";
   FileWriteString(ExtHandle,str,StringLen(str));
   for(int i=0; i<ExtSymbolsTotal; i++)
     {
      int    digits=MarketInfo(ExtSymbols[i],MODE_DIGITS);
      double buy_lots=ExtSymbolsSummaries[i][BUY_LOTS];
      double sell_lots=ExtSymbolsSummaries[i][SELL_LOTS];
      double buy_price=0.0;
      double sell_price=0.0;
      if(buy_lots!=0)  buy_price=ExtSymbolsSummaries[i][BUY_PRICE]/buy_lots;
      if(sell_lots!=0) sell_price=ExtSymbolsSummaries[i][SELL_PRICE]/sell_lots;
      str=StringConcatenate("<td>",ExtSymbols[i],"</td>",
                "<td>",DoubleToStr(ExtSymbolsSummaries[i][DEALS],0),"</td>",
                "<td>",DoubleToStr(buy_lots,2),"</td>",
                "<td>",DoubleToStr(buy_price,digits),"</td>",
                "<td>",DoubleToStr(sell_lots,2),"</td>",
                "<td>",DoubleToStr(sell_price,digits),"</td>",
                "<td>",DoubleToStr(buy_lots-sell_lots,2),"</td>",
                "<td>",DoubleToStr(ExtSymbolsSummaries[i][PROFIT],2),"</td></tr>\r\n");
      FileWriteString(ExtHandle,str,StringLen(str));
     }
//----
   str="</table>\r\n</div></body></html>\r\n";
   FileWriteString(ExtHandle,str,StringLen(str));
  }
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void WriteText()
  {
   ExtHandle=FileOpen(ExtFileName,FILE_CSV|FILE_WRITE,'\t');
   if(ExtHandle<0) return;
//----
   FileWrite(ExtHandle,"Symbols",
                       "Deals",
                       "Buy lots",
                       "Buy price",
                       "Sell lots",
                       "Sell price",
                       "Net lots",
                       "Profit");
   for(int i=0; i<ExtSymbolsTotal; i++)
     {
      int    digits=MarketInfo(ExtSymbols[i],MODE_DIGITS);
      double buy_lots=ExtSymbolsSummaries[i][BUY_LOTS];
      double sell_lots=ExtSymbolsSummaries[i][SELL_LOTS];
      double buy_price=0.0;
      double sell_price=0.0;
      if(buy_lots!=0)  buy_price=ExtSymbolsSummaries[i][BUY_PRICE]/buy_lots;
      if(sell_lots!=0) sell_price=ExtSymbolsSummaries[i][SELL_PRICE]/sell_lots;
      FileWrite(ExtHandle,ExtSymbols[i],
                DoubleToStr(ExtSymbolsSummaries[i][DEALS],0),
                DoubleToStr(buy_lots,2),
                DoubleToStr(buy_price,digits),
                DoubleToStr(sell_lots,2),
                DoubleToStr(sell_price,digits),
                DoubleToStr(buy_lots-sell_lots,2),
                DoubleToStr(ExtSymbolsSummaries[i][PROFIT],2));
     }
  }
//+------------------------------------------------------------------+